@@ -1,11 +1,15 @@
 import sys
 import os
 from argparse import Action
-import json
 import filetype
 from terraform_compliance.common.terraform_files import convert_terraform_plan_to_json
 from terraform_compliance.common.exceptions import TerraformComplianceInternalFailure
 
+try:
+    import orjson as json
+except ImportError:
+    import json
+
 
 class ReadablePlan(Action):
     def __init__(self, option_strings, dest, **kwargs):
@@ -37,8 +41,7 @@ class ReadablePlan(Action):
 
         # Check if the given file is a json file.
         try:
-            with open(values, 'r', encoding='utf-8') as plan_file:
-                plan_lines = plan_file.read().splitlines()
+            plan_lines = [line for line in open(values, 'r', encoding='utf-8')]
 
             # Some Github Actions (hashicorp/setup-terraform) has internal wrappers which is
             # breaking the json file that is read by the terraform-compliance
@@ -56,7 +59,7 @@ class ReadablePlan(Action):
                 with open(values, 'w', encoding='utf-8') as plan_file:
                     plan_file.write(plan_lines)
 
-        except json.decoder.JSONDecodeError:
+        except json.JSONDecodeError:
             print('ERROR: {} is not a valid JSON file'.format(values))
             sys.exit(1)
         except UnicodeDecodeError:
@@ -74,7 +77,7 @@ class ReadablePlan(Action):
 
             # Check if this is a state file
             if 'values' in data:
-                assert data['values']['root_module']['resources']
+                assert data['values']['root_module'].get('resources', data['values']['root_module'].get('child_modules'))
 
             # Then it must be a terraform plan file
             else:
