@@ -3,6 +3,7 @@ from radish.utils import console_write
 from radish import custom_type
 from radish import world
 from terraform_compliance.common.defaults import Defaults
+from terraform_compliance.common.error_handling import Error
 
 
 def skip_step(step, resource=None, message=None):
@@ -13,9 +14,18 @@ def skip_step(step, resource=None, message=None):
         message = '{} {} {}'.format(Defaults().yellow('Can not find'),
                                     Defaults().green(resource),
                                     Defaults().yellow('defined in target terraform plan.'))
+        e_message = 'Can not find {} defined in target terraform plan.'.format(resource)
     else:
+        e_message = message
         message = Defaults().yellow(message)
 
+
+    if step.context.no_skip:
+        if -1 in step.context.lines_to_noskip or step.line in step.context.lines_to_noskip:
+            message = Defaults().failure_colour(message)
+            Error(step, e_message)
+            return
+    
     if str(world.config.formatter) in ('gherkin'):
         console_write("\t{} {}: {}".format(Defaults().info_icon,
                                            Defaults().skip_colour('SKIPPING'),
