@@ -8,7 +8,6 @@ from terraform_compliance.common.helper import (
     remove_mounted_resources,
     transform_asg_style_tags,
     convert_resource_type,
-    recursive_jsonify
 )
 from terraform_compliance.extensions.ext_radish_bdd import skip_step
 import re
@@ -41,11 +40,13 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
 
     if not hasattr(_step_obj.context, 'cumulative_stash'):
         _step_obj.context.cumulative_stash = []
+    if not hasattr(_step_obj.context, 'stash'):
+        _step_obj.context.stash = []
 
     if name in ('a resource', 'any resource', 'resources'):
         _step_obj.context.type = type_name
         _step_obj.context.name = name
-        _step_obj.context.stash = recursive_jsonify([obj for key, obj in _terraform_config.config.terraform.resources_raw.items()])
+        _step_obj.context.stash = [obj for key, obj in _terraform_config.config.terraform.resources_raw.items()]
         _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
         _step_obj.context.addresses = get_resource_address_list_from_stash(_step_obj.context.stash)
         _step_obj.context.property_name = type_name
@@ -54,7 +55,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
     elif name in ('an output', 'any output', 'outputs'):
         _step_obj.context.type = 'output'
         _step_obj.context.name = name
-        _step_obj.context.stash = recursive_jsonify([obj for key, obj in _terraform_config.config.terraform.configuration['outputs'].items()])
+        _step_obj.context.stash = [obj for key, obj in _terraform_config.config.terraform.configuration['outputs'].items()]
         _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
         _step_obj.context.addresses = get_resource_address_list_from_stash(_terraform_config.config.terraform.configuration['outputs'])
         _step_obj.context.property_name = 'output'
@@ -63,7 +64,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
     elif name in ('a variable', 'any variable', 'variables'):
         _step_obj.context.type = 'variable'
         _step_obj.context.name = name
-        _step_obj.context.stash = recursive_jsonify([obj for key, obj in _terraform_config.config.terraform.configuration['variables'].items()])
+        _step_obj.context.stash = [obj for key, obj in _terraform_config.config.terraform.configuration['variables'].items()]
         _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
         _step_obj.context.addresses = 'variable'
         _step_obj.context.property_name = 'variable'
@@ -93,7 +94,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
         if resource_list:
             _step_obj.context.type = type_name
             _step_obj.context.name = name
-            _step_obj.context.stash = recursive_jsonify(resource_list)
+            _step_obj.context.stash = resource_list
             _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
             _step_obj.context.addresses = get_resource_address_list_from_stash(resource_list)
             _step_obj.context.property_name = type_name
@@ -106,7 +107,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
         if resource_list:
             _step_obj.context.type = type_name
             _step_obj.context.name = name
-            _step_obj.context.stash = recursive_jsonify(resource_list)
+            _step_obj.context.stash = resource_list
             _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
             _step_obj.context.addresses = get_resource_address_list_from_stash(resource_list)
             _step_obj.context.property_name = type_name
@@ -118,7 +119,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
         if found_variable:
             _step_obj.context.type = type_name
             _step_obj.context.name = name
-            _step_obj.context.stash = [recursive_jsonify(found_variable)]
+            _step_obj.context.stash = [found_variable]
             _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
             _step_obj.context.addresses = name
             _step_obj.context.property_name = type_name
@@ -130,7 +131,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
         if found_output:
             _step_obj.context.type = type_name
             _step_obj.context.name = name
-            _step_obj.context.stash = recursive_jsonify(found_output)
+            _step_obj.context.stash = found_output
             _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
             _step_obj.context.addresses = name
             _step_obj.context.property_name = type_name
@@ -142,7 +143,7 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
         if found_provider:
             _step_obj.context.type = type_name
             _step_obj.context.name = name
-            _step_obj.context.stash = recursive_jsonify(found_provider)
+            _step_obj.context.stash = found_provider
             _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
             _step_obj.context.addresses = name
             _step_obj.context.address = name
@@ -156,11 +157,11 @@ def i_have_name_section_configured(_step_obj, name, type_name='resource', _terra
         if data_list:
             _step_obj.context.type = type_name
             _step_obj.context.name = name
-            _step_obj.context.stash = recursive_jsonify(data_list)
+            _step_obj.context.stash = data_list
             _step_obj.context.cumulative_stash.extend(_step_obj.context.stash)
             _step_obj.context.addresses = name
             _step_obj.context.address = name
             _step_obj.context.property_name = type_name
             return True
 
-    skip_step(_step_obj, name)
+    skip_step(_step_obj, name)
\ No newline at end of file
